import React from 'react';
import PropTypes from 'prop-types';
import { Spin, Tag } from 'antd';
import PTUtil from '../../utils/pt-util';
import './technologies.less';

export default class Technologies extends React.Component {
  static propTypes = {
    technologies: PropTypes.array.isRequired,
    onTechClick: PropTypes.func.isRequired,
    technologyCurrent: PropTypes.string,
    children: PropTypes.node,
    className: PropTypes.string,
    loading: PropTypes.bool,
  };
  static defaultProps ={
    technologyCurrent: '',
    children: null,
    className: '',
    loading: false,
  };
  shouldComponentUpdate(nextProps) {
    const prev = {
      technologies: this.props.technologies,
      technologyCurrent: this.props.technologyCurrent,
      className: this.props.className,
      children: this.props.children,
      loading: this.props.loading,
    };
    const next = {
      technologies: nextProps.technologies,
      technologyCurrent: nextProps.technologyCurrent,
      className: nextProps.className,
      children: nextProps.children,
      loading: nextProps.loading,
    };
    return !PTUtil.is(prev, next);
  }
  render() {
    const {
      technologies, technologyCurrent, className, children, loading, onTechClick,
    } = this.props;
    return (
      <div className={`home-technologies-wrapper ${className}`}>
        <h3>相关技术</h3>
        {children}
        <Spin spinning={loading}>
          <div className="home-technologies-list">
            {
              technologies.map((name, index) => (
                <Tag
                  key={index}
                  color={technologyCurrent && name === technologyCurrent ? 'blue' : ''}
                  onClick={() => onTechClick(name)}
                >{name}
                </Tag>
              ))
            }
          </div>
        </Spin>
      </div>
    );
  }
}
