import { notification } from 'antd';
import { fromJS, is } from 'immutable';
import { HTTP_METHOD, TOKEN } from '../constants/const';
import FetchUtil from './fetch-util';

const SESSION = {
  set: (key, value) => {
    sessionStorage.setItem(key, value);
  },
  get: key => sessionStorage.getItem(key),
  delete: (key) => {
    sessionStorage.removeItem(key);
  },
};

const LOCAL = {
  set: (key, value) => {
    localStorage.setItem(key, value);
  },
  get: key => localStorage.getItem(key),
  delete: (key) => {
    localStorage.removeItem(key);
  },
};

const getHeaders = () => ({
  'Content-Type': 'application/json;charset=utf-8',
  Authorization: SESSION.get(TOKEN),
});

const HttpRequest = {
  GET: () => {
    const fetchUtil = new FetchUtil();
    return fetchUtil
      .init()
      .setMethod(HTTP_METHOD.GET)
      .setHeader(getHeaders());
  },
  POST: () => {
    const fetchUtil = new FetchUtil();
    return fetchUtil
      .init()
      .setMethod(HTTP_METHOD.POST)
      .setBodyType('json')
      .setHeader(getHeaders());
  },
  PUT: () => {
    const fetchUtil = new FetchUtil();
    return fetchUtil
      .init()
      .setMethod(HTTP_METHOD.PUT)
      .setBodyType('json')
      .setHeader(getHeaders());
  },
  DELETE: () => {
    const fetchUtil = new FetchUtil();
    return fetchUtil
      .init()
      .setMethod(HTTP_METHOD.DELETE)
      .setHeader(getHeaders());
  },
};

const PTUtil = {
  each: require('lodash/each'),
  map: require('lodash/map'),
  isObject: require('lodash/isObject'),
  isNumber: require('lodash/isNumber'),
  isString: require('lodash/isString'),
  isFunction: require('lodash/isFunction'),
  isFinite: require('lodash/isFinite'),
  isBoolean: require('lodash/isBoolean'),
  isEmpty: require('lodash/isEmpty'),
  lowerFirst: require('lodash/lowerFirst'),
  upperFirst: require('lodash/upperFirst'),
  upperCase: require('lodash/upperCase'),
  isNil: require('lodash/isNil'),
  isNull: require('lodash/isNull'),
  isArray: require('lodash/isArray'),
  isDate: require('lodash/isDate'),
  isPlainObject: require('lodash/isPlainObject'),
  toArray: require('lodash/toArray'),
  indexOf: require('lodash/indexOf'),
  assign: require('lodash/assign'),
  groupBy: require('lodash/groupBy'),
  cloneDeep: require('lodash/cloneDeep'),
  maxBy: require('lodash/maxBy'),
  minBy: require('lodash/minBy'),
  round: require('lodash/round'),
  filter: require('lodash/filter'),
  isEqualWith: require('lodash/isEqualWith'),
  isEqual: require('lodash/isEqual'),
  replace: require('lodash/replace'),
  union: require('lodash/union'),
  pick: require('lodash/pick'),
  uniq: require('lodash/uniq'),
  trim: require('lodash/trim'),
  isUndefined: require('lodash/isUndefined'),
  sortBy: require('lodash/sortBy'),
  is: (first, second) => (is(fromJS(first), fromJS(second))),
  isFetchCodeNice: code => /^SC_2[0-6]{2}$/.test(code),
  SESSION,
  LOCAL,
  HttpRequest,
  getUrlPrefix: () => {
    const env = process.env.NODE_ENV;
    if (env.indexOf('server') !== -1) {
      return 'http://localhost:7070/';
    }
    return '/';
  },
  openNotification(type, title, duration, description, key) {
    notification[type]({
      message: PTUtil.isEmpty(title) ? '提示信息' : title,
      description,
      duration,
      key,
      style: {
        marginTop: '50px',
      },
    });
  },
  redirect: (meta) => {
    if (
      meta.code === 'SC_405' &&
      (meta.message === 'token expired.' || meta.message === 'invalid token.')
    ) {
      window.location.href = '/#/login';
      return true;
    }
    return false;
  },
  buildRequest: prefix => ({
    REQUEST: `${prefix}_REQUEST`,
    SUCCESS: `${prefix}_SUCCESS`,
    FAIL: `${prefix}_FAIL`,
  }),
  getArrRandom: (arr, num) => {
    const tempArray = [...arr];
    const returnArray = [];
    for (let i = 0; i < num; i++) {
      if (tempArray.length > 0) {
        const arrIndex = Math.floor(Math.random() * tempArray.length);
        returnArray[i] = tempArray[arrIndex];
        tempArray.splice(arrIndex, 1);
      } else {
        break;
      }
    }
    return returnArray;
  },
};

export default PTUtil;
